%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Wessels, L, Reinders, M.
%                     Detecting statistically significant 
%                     common insertion sites in retroviral
%                     insertional mutagenesis screens.
%                     PLoS Comput Biol, 2006, 2, e166
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [rise_intersect descent_intersect] = get_intersect(x,densdat,T);
%T always >0 and x(:) always >0
T = double(T);
densdat = double(densdat);
x                   = x(:);
densdat             = densdat(:);
%Subtract the threshold level
diffvec             = densdat-T;
%Convert to a bistate vector
bistate             = zeros(size(diffvec));
bistate(diffvec>=0) = 1;
bistate(diffvec<0)  = -1;
%Find the zero crossings
trans_vec           = bistate(1:end-1)-bistate(2:end);
%below = -1 to above = 1 ==> -1 - 1 = -2
rise_intersect      = find(trans_vec==-2);
%above = 1 to below = -1 ==> 1 - -1 = 2
descent_intersect   = find(trans_vec==2);

rise_start_x        = x(rise_intersect);
rise_end_x          = x(rise_intersect+1);
rise_start_y        = densdat(rise_intersect);
rise_end_y          = densdat(rise_intersect+1);
rise_intersect      = (((rise_end_x-rise_start_x).*(T-rise_start_y))...
    ./(rise_end_y-rise_start_y)) +rise_start_x;

descent_start_x       = x(descent_intersect);
descent_end_x         = x(descent_intersect+1);
descent_start_y        = densdat(descent_intersect);
descent_end_y          = densdat(descent_intersect+1);
descent_intersect      = descent_end_x - ((descent_end_x-descent_start_x).*(T-descent_end_y))...
    ./(descent_start_y-descent_end_y);



