%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Wessels, L, Reinders, M.
%                     Detecting statistically significant 
%                     common insertion sites in retroviral
%                     insertional mutagenesis screens.
%                     PLoS Comput Biol, 2006, 2, e166
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [max_pos, max_val] = get_local_max(x);

% get_local_max   Computes local maxima.
%                 [max_pos, max_val] = get_local_max(x, pos) determines
%                 the position and value of the three-point maxima in
%                 the sequence x, starting from position pos (default 
%                 pos = 1). 

% ensure that x is a column vector
x = x(:);
% Differentiate and find maxima's
diffvec             = x(2:end)-x(1:end-1);
%Make a tri-state vector indicating the transitions
tristate            = zeros(size(diffvec));
tristate(diffvec>0) =1; tristate(diffvec==0)=0; tristate(diffvec<0)=-1;
%remove the flat parts
non_flat_index      = find(tristate~=0);
bistate             = tristate(tristate~=0);
%Find the 1-->-1 transitions
trans_vec           = bistate(1:end-1)-bistate(2:end);
trans_index         = find(trans_vec==2);
if isempty(trans_index)
    warning('No local maxima!')
    max_pos = []; max_val = [];
    return
end
max_pos             = non_flat_index(trans_index)+1;
max_val             = x(max_pos);