%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Wessels, L, Reinders, M.
%                     Detecting statistically significant 
%                     common insertion sites in retroviral
%                     insertional mutagenesis screens.
%                     PLoS Comput Biol, 2006, 2, e166
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [min_pos, min_val] = get_local_min(x)

% ensure that x is a column vector
x = x(:);

% Differentiate and find maxima's
diffvec = x(2:end)-x(1:end-1);
%Make a tri-state vector indicating the transitions
tristate = zeros(size(diffvec));
tristate(diffvec>0)=1; tristate(diffvec==0)=0; tristate(diffvec<0)=-1;
%remove the flat parts
non_flat_index = find(tristate~=0);
bistate = tristate(non_flat_index);
%Find the 1-->-1 transitions
trans_vec = bistate(1:end-1)-bistate(2:end);
%descent = -1 to rise = 1 ==> -1 - 1 = -2
trans_index = find(trans_vec==-2);
if isempty(trans_index)
    error('No local minima!')
    min_pos = []; min_val = [];
    return
end
min_pos = non_flat_index(trans_index)+1;
min_val = x(min_pos);