%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Wessels, L, Reinders, M.
%                     Detecting statistically significant 
%                     common insertion sites in retroviral
%                     insertional mutagenesis screens.
%                     PLoS Comput Biol, 2006, 2, e166
%
%  function :kernelconv(in,x,h,window)
%  Purpose  :Kernel based (parzen) density estimator
%            Normalized to K(0) = 1
%  Inputs   :- in     : input data
%            - x      : Samples to evaluate
%            - h      : smoothing parameter (bandwidth)
%            - window :
%               ~ 'rect' : rectangular window
%               ~ 'gauss': gaussian window
%            - p      : 1 will plot the result
%
% Outputs   :- out    :output vector
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Reference:
%  [1] Webb, A., Statistical Pattern Recognition, 2nd ed.
%       p. 108
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [out] = kernelconv_fast(in,x,h)
%an x cannot be further apart from an in than 10*h
%First make partitioning of the data (x and in must be sorted)
% in = in(:);
% x = x(:);
bound = -5*h:5*h:max(x)+5*h;
Nx = [0; 0; histc(x(:),bound)];
Nin = [0; 0; histc(in(:),bound)];
indexx = cumsum(Nx)+1;
indexin = cumsum(Nin)+1;

out = zeros(length(x),1);
hprime = sqrt(0.5)*h;
cnt = 1;
for binindex = 1:length(Nx)
    if Nx(binindex)~=0
        inbin = in(indexin(binindex-2):indexin(binindex+1)-1); %Select input data of current bin + two neighboring bins
        xbin = x(indexx(binindex-1):indexx(binindex)-1);%Select sample data of current bin + two neighboring bins
        for i = 1:length(xbin)
            temp = (xbin(i)-inbin)/hprime; %h is full width
            %            I = find(); %After this the gauss curve is almost 0
            out(cnt) = sum(exp(-(temp.^2)));
            cnt = cnt+1;
        end
    end
end