%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Wessels, L, Reinders, M.
%                     Detecting statistically significant 
%                     common insertion sites in retroviral
%                     insertional mutagenesis screens.
%                     PLoS Comput Biol, 2006, 2, e166
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function plot_tracks(handles)
%There are 3 Possible actions:  Plot low detail (remove detail, show only always show tracks)
%                               Plot detail (also show track 2 through 5)
%Just make sure there is a plotflag present
if ~isfield(handles,'plot_flag')
    handles.plot_flag = 0;
end
track_struct    = handles.track_struct;
track_height    = handles.track_height;
show_threshold  = handles.show_threshold;

set(handles.track_axes,'drawmode','fast','nextplot','add',...
    'ydir','reverse','ylim',[0.5 5.5]);

%Plot LOW DETAIL (and remove detail if present)
if (abs(handles.end_view-handles.start_view(1))>=show_threshold)
    delete(get(handles.track_axes,'children'));
    axes(handles.track_axes);
    %Replot Always Show tracks
    for track = 1:length(track_struct)
        if track_struct(track).enable && track_struct(track).always_show
            for i = 1:track_struct(track).numel
                x               = track_struct(track).x{i};
                offset          = track; %Select track one
                color           = track_struct(track).color{i};

                if strcmp(track_struct(track).style,'insertion')
                    H{i} = line([x(:) x(:)]',...
                        repmat([offset+track_height/2; offset-track_height/2],[1 length(x)]),...
                        'color',color);
                elseif strcmp(track_struct(track).style,'gene')
                    if i>1 % Plot only the subset of genes
                        % TOP STRAND
                        xtop = x(track_struct(track).orientation==1,:);
                        H{i} = line([xtop(:,1) xtop(:,2)]',...
                            offset.*ones(2,length(x{1}))+0.4,'color','r','linewidth',track_height*5);
                        % BOTTOM STRAND
                        xbot = x(track_struct(track).orientation==-1,:);
                        H{i+1} = line([xbot(:,1) xbot(:,2)]',...
                            offset.*ones(2,length(x{2}))-0.4,'color','r','linewidth',track_height*5);
                    end
                else
                    error('Unknown tracktype');
                end
            end
        end
    end
    %Set correct label
    for i = 1:5
        set(handles.label_track(i),'string',track_struct(i).label);
    end
    handles.plot_flag = 0;
    %PLOT DETAIL
elseif ~handles.plot_flag
    delete(get(handles.track_axes,'children'));
    axes(handles.track_axes);
    for track = 1:length(track_struct)
        if track_struct(track).enable
            for i = 1:track_struct(track).numel
                x               = track_struct(track).x{i};
                offset          = track; %Select track one
                color           = track_struct(track).color{i};
                if strcmp(track_struct(track).style,'insertion')
                    x = x(x>handles.start_view&x<handles.end_view);
                    H{i} = line([x(:) x(:)]',...
                        repmat([offset+track_height/2; offset-track_height/2],[1 length(x)]),...
                        'color',color);
                elseif strcmp(track_struct(track).style,'gene')
                    % TOP STRAND
                    I = find(x{1}(:,2)>handles.start_view&x{1}(:,1)<handles.end_view);
                    xtop = x{1}(I,:);
                    H{i+(i-1)} = line([xtop(:,1) xtop(:,2)]',...
                        offset.*ones(2,size(xtop,1))-0.2,'color','g','linewidth',track_height*6);
                    set(H{i+(i-1)},'buttondownfcn',@gene_clickfcn_top);
                    H_vert = line([[xtop(:,1); xtop(:,2)] [xtop(:,1); xtop(:,2)]]',...
                        repmat([offset+track_height/2-0.4; offset-track_height/2],[1 2*size(xtop,1)]),...
                        'color','r');
                    if i>1 %MAKE THE GENES in the curated data RED
                        [dummy, I_red, dummy] = intersect(xtop(:,1),x{1}(:,1));
                        set(H{i+(i-1)}(I_red),'color','r');
                        plot((x{1}(:,1)+x{1}(:,2))/2,ones(size(x{1}(:,1)))*offset,'*k');
                    end

                    % BOTTOM STRAND
                    I = find(x{2}(:,2)>handles.start_view&x{2}(:,1)<handles.end_view);
                    xbot = x{2}(I,:);
                    H{i+(i-1)+1} = line([xbot(:,1) xbot(:,2)]',...
                        offset.*ones(2,size(xbot,1))+0.2,'color','g','linewidth',track_height*6);
                    set(H{i+(i-1)+1},'buttondownfcn',@gene_clickfcn_bot);
                    dummy = line([[xbot(:,1); xbot(:,2)] [xbot(:,1); xbot(:,2)]]',...
                        repmat([offset+track_height/2; offset-track_height/2+0.4],[1 2*size(xbot,1)]),...
                        'color','b');
                    if i>1 %MAKE THE GENES in the curated data RED
                        [dummy, I_red, dummy] = intersect(xbot(:,1),x{2}(:,1));
                        set(H{i+(i-1)+1}(I_red),'color','r');
                        plot((x{2}(:,1)+x{2}(:,2))/2,ones(size(x{2}(:,1)))*offset,'*k');
                    end
                    %NAMES ABOVE THE GENES
                    if size(xtop,1)+size(xbot,1)<handles.gene_name_threshold
                        top             = handles.top;
                        bot             = handles.bot;
                        %TOP STRAND
                        I = find(x{1}(:,2)>handles.start_view&x{1}(:,1)<handles.end_view);
                        [dummy,I_sort] = sort(top.prime5(I));
                        I = I(I_sort);
                        last_x = 0;
                        step = 0;
                        for jj = 1:length(I)
                            if (top.prime5(I(jj))-last_x)<(handles.end_view-handles.start_view)/15
                                step = step+0.35;
                            else
                                step = 0;
                            end
                            if ~strcmp('',top.EID{I(jj)})
                                text(top.prime5(I(jj)),offset-0.75-step,top.EID{I(jj)},'fontsize',10,...
                                    'interpreter','none');
                            else
                                text(top.prime5(I(jj)),offset-0.75-step,top.GID{I(jj)},'fontsize',10,...
                                    'interpreter','none');
                            end
                            last_x = top.prime5(I(jj));
                        end
                        % BOTTOM STRAND
                        I = find(x{2}(:,2)>handles.start_view&x{2}(:,1)<handles.end_view);
                        [dummy,I_sort] = sort(bot.prime5(I),'descend');
                        I = I(I_sort);
                        last_x = 0;
                        step = 0;
                        for jj = 1:length(I)
                            if (last_x-bot.prime5(I(jj)))<(handles.end_view-handles.start_view)/15
                                step = step+0.35;
                            else
                                step = 0;
                            end
                            if ~strcmp('',bot.EID{I(jj)})
                                text(bot.prime5(I(jj)),offset+0.75+step,bot.EID{I(jj)},'fontsize',10,...
                                    'interpreter','none','horizontalalignment','right');
                            else
                                text(bot.prime5(I(jj)),offset+0.75+step,bot.GID{I(jj)},'fontsize',10,...
                                    'interpreter','none','horizontalalignment','right');
                            end
                            last_x = bot.prime5(I(jj));
                        end
                    end
                    %EXON STRUCTURE OF THE GENES
                    if size(xtop,1)+size(xbot,1)<handles.exon_show_threshold &&...
                        isfield(handles,'g_struct_top');                        
                        s_top             = handles.g_struct_top;
                        s_bot             = handles.g_struct_bot;
                        top             = handles.top;
                        bot             = handles.bot;
                        %TOP STRAND
                        I = find(x{1}(:,2)>handles.start_view&x{1}(:,1)<handles.end_view);
                        [dummy,I_sort] = sort(top.prime5(I));
                        I = I(I_sort);
                        for jj = 1:length(I)
                            sI = find(strcmp(s_top.GID,top.GID{I(jj)}));
                            ex_start = s_top.ex_start(sI);
                            ex_end   = s_top.ex_end(sI);
                            line([ex_start(:) ex_end(:)]',...
                                offset.*ones(2,size(ex_start,1))-0.2,'color','k','linewidth',track_height*6);
                            line([[ex_start(:); ex_end(:)] [ex_start(:); ex_end(:)]]',...
                                repmat([offset+track_height/2-0.4; offset-track_height/2],[1 2*size(ex_start,1)]),...
                                'color','k');
                        end
                        % BOTTOM STRAND
                        I = find(x{2}(:,2)>handles.start_view&x{2}(:,1)<handles.end_view);
                        [dummy,I_sort] = sort(bot.prime5(I),'descend');
                        I = I(I_sort);
                        for jj = 1:length(I)
                            sI = find(strcmp(s_bot.GID,bot.GID{I(jj)}));
                            ex_start = s_bot.ex_start(sI);
                            ex_end   = s_bot.ex_end(sI);
                            line([ex_start(:) ex_end(:)]',...
                                offset.*ones(2,size(ex_start,1))+0.2,'color','k','linewidth',track_height*6);
                            line([[ex_start(:); ex_end(:)] [ex_start(:); ex_end(:)]]',...
                                repmat([offset+track_height/2; offset-track_height/2+0.4],[1 2*size(ex_start,1)]),...
                                'color','k');
                         end
                    end
                else
                    error('Unknown tracktype');
                end
            end
            %Set correct label
            set(handles.label_track(i),'string',track_struct(i).label);
        end
    end
    handles.plot_flag = 1;
else
    %Do nothing for now...
end
