%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Wessels, L, Reinders, M.
%                     Detecting statistically significant 
%                     common insertion sites in retroviral
%                     insertional mutagenesis screens.
%                     PLoS Comput Biol, 2006, 2, e166
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function refresh_zoom(handles)
axisvar         = [handles.start_view handles.end_view];
show_threshold  = handles.show_threshold;
line_zoom_limit = handles.line_zoom_limit;
%Set actual axes property
set(handles.density_axes,'xlim',sort(axisvar));
set(handles.track_axes,'xlim',sort(axisvar));
set(handles.scale_space_axes,'xlim',sort(axisvar));
%Convert to chromosome plus offset
[chrom_start,offset_start] = abs2chrom(axisvar(1),...
    handles.data_struct.chrom_l,1); %Output as string
[chrom_end,offset_end] = abs2chrom(axisvar(2),...
    handles.data_struct.chrom_l,1); %Output as string
% %Set the chromosome readout
% set(handles.zoom_chrom1,'string',chrom_start);
% set(handles.zoom_chrom2,'string',chrom_end);
% set(handles.zoom_offset1,'string',offset_start);
% set(handles.zoom_offset2,'string',offset_end);
%Check if we are zoomed within one chromosome
if strcmp(chrom_end,chrom_start)
    %Set the current view
    handles = guidata(hObject);
    [chrom_start,offset_start] = abs2chrom(axisvar(1),...
        handles.data_struct.chrom_l,0);
    [chrom_end,offset_end] = abs2chrom(axisvar(2),...
        handles.data_struct.chrom_l,0);
    set(handles.zoom_axes,'xlim',...
        [0 handles.data_struct.chrom_l(chrom_start)],'ylim',[0 1]);
    axes(handles.zoom_axes);
    try
        delete(get(handles.zoom_axes,'children'))
    end
    %Make sure the patch is visible
    dX = offset_start+max(line_zoom_limit,offset_end-offset_start);
    patch([offset_start dX dX offset_start],[0 0 1 1],'y');
    %Set chromosome relative tickmarks in the scale_space axis
    %Generate 4 ticks relative to the chromosome start
    ticklist = offset_start:round((offset_end-offset_start)/7):offset_end;
    ticklist = unique(round(ticklist/1000)); %Convert to kilobases
    tickstring = [num2str(ticklist') repmat(' kb',length(ticklist),1)];
    ticklist = ticklist*1000+handles.chrom_l(chrom_start);
    set(handles.scale_space_axes,'xticklabel',tickstring,'xtick',ticklist);
else %Remove the current view
    try
        delete(get(handles.zoom_axes,'children'))
    end
    set(handles.scale_space_axes,'xtick',[]);
end
%Reset the gene information
set(handles.ENSID,'string','...');
set(handles.description,'string','...');
%Show a scale
try
    delete(handles.h_scale)
end
scale = handles.data_struct.kernel_width;
x_start_pos = (axisvar(2)-axisvar(1))*0.05+axisvar(1);
y_start_pos = get(handles.density_axes,'ylim');
y_start_pos = y_start_pos(2)*0.9;
axes(handles.density_axes);
handles.h_scale(1) = text(x_start_pos,y_start_pos,['Scale: ' num2str(scale)]);
handles.h_scale(2) = line([x_start_pos x_start_pos+scale],...
    [y_start_pos-y_start_pos*0.05 y_start_pos-y_start_pos*0.05],'color','k');
handles.h_scale(3) = line([x_start_pos x_start_pos],...
    [y_start_pos-y_start_pos*0.07 y_start_pos-y_start_pos*0.03],...
    'color','k');
handles.h_scale(4) = line([x_start_pos+scale x_start_pos+scale],...
    [y_start_pos-y_start_pos*0.07 y_start_pos-y_start_pos*0.03],...
    'color','k');