%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Wessels, L, Reinders, M.
%                     Detecting statistically significant 
%                     common insertion sites in retroviral
%                     insertional mutagenesis screens.
%                     PLoS Comput Biol, 2006, 2, e166
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function data_struct = parseRTCGDdata(cum_chrom_l)
%o denotes fields we do not use.
    [TID,o,model,o,o,o,o,o,o,o,o,chrom,loc,o] = textread('RTCGD_mm8_RV010307.txt',...
   '%s%s%s%s%s%s%s%s%s%s%s%s%n%s',...
   'headerlines',1,'delimiter','\t','emptyvalue',-1);

%Filter unmapped ones
I_keep = cellfun(@isempty,(strfind(chrom,'random')));
data_struct.chr = chrom(I_keep);
data_struct.chr = char(data_struct.chr);
data_struct.chr = data_struct.chr(:,4:end);

I_x = strcmp(cellstr(data_struct.chr),'X');
I_y = strcmp(cellstr(data_struct.chr),'Y');

data_struct.chr(I_x,[1 2]) = repmat('20',length(find(I_x)),1);
data_struct.chr(I_y,[1 2]) = repmat('21',length(find(I_y)),1);
data_struct.chr =str2num(data_struct.chr); %#ok<ST2NM>

N = length(data_struct.chr);

data_struct.genoType = model(I_keep);
data_struct.tissueID = TID(I_keep);
data_struct.median_coord = loc(I_keep) + cum_chrom_l(data_struct.chr);
%below obsolete identifiers that need to be set for backward compat.
data_struct.contig_depth = ones(N,1);
data_struct.sampleID = ones(N,1);
data_struct.screenID = ones(N,1);
data_struct.start = ones(N,1);
data_struct.end = ones(N,1);
data_struct.ori = ones(N,1);
data_struct.mean_coord = ones(N,1);
data_struct.enzyme = ones(N,1);





