clear
[GID, chrom, g_start, g_end, strand, descr, EID] =...
    textread('ENSEMBL_genes_build36.txt','%s%s%n%n%n%s%s',...
    'headerlines',1,'delimiter','\t');

load chrom_l
chrom_l = [0; cumsum(chrom_l)];

I1                  = find(~cellfun('isempty',strfind(chrom,'MT')));
I2                  = find(~cellfun('isempty',strfind(chrom,'NT')));

chrom([I1; I2])     = [];
IX                  = find(strcmp(chrom,'X'));
IY                  = find(strcmp(chrom,'Y'));
chrom               = char(chrom);
chrom(IX,:)         = repmat('20',size(IX,1),1);
chrom(IY,:)         = repmat('21',size(IY,1),1);
chrom               = str2num(chrom);
g_start([I1; I2])   = [];
g_end([I1; I2])     = [];
strand([I1; I2])	= [];
GID([I1; I2])       = [];
EID([I1; I2])       = [];
descr([I1; I2])     = [];


[uGID uI]            = unique(GID);

g_top_5prime   = [];
g_top_3prime   = [];
tss_top        = [];
g_bot_5prime   = [];
g_bot_3prime   = [];
tss_bot        = [];
descr_top      = [];
EID_top        = [];
descr_bot      = [];
EID_bot        = [];
GID_top        = [];
GID_bot        = [];
chrom_top      = [];
chrom_bot      = [];

h = waitbar(0,'Processing genes build 36');
for i = 1:length(uGID)
    waitbar(i/length(uGID));
    I = find(strcmp(uGID{i},GID));
    if abs(sum(strand(I)))~=length(I), error('multiple strands detected'); end
    if strand(I(1))==1
        g_top_5prime   = [g_top_5prime; min(g_start(I))];
        g_top_3prime   = [g_top_3prime; max(g_end(I))];
        tss_top        = [tss_top; unique(g_start(I))];
        chrom_top      = [chrom_top; chrom(I(1))];
        descr_top      = [descr_top; descr(I(1))];
        GID_top        = [GID_top; uGID(i)];
        EID_top        = [EID_top; EID(I(1))];
    elseif strand(I(1))==-1
        g_bot_5prime   = [g_bot_5prime; max(g_end(I))];
        g_bot_3prime   = [g_bot_3prime; min(g_start(I))];
        tss_bot        = [tss_bot; unique(g_end(I))];
        chrom_bot      = [chrom_bot; chrom(I(1))];
        descr_bot      = [descr_bot; descr(I(1))];
        GID_bot        = [GID_bot; uGID(i)];
        EID_bot        = [EID_bot; EID(I(1))];
    else
        error('wrong strand');
    end
end
close(h);

%check
if sum(g_bot_5prime>g_bot_3prime)~=length(g_bot_5prime), error('1'); end
if sum(g_top_5prime<g_top_3prime)~=length(g_top_5prime), error('2'); end

annotation_struct.info          = 'ENSEMBL Genes build 36';
annotation_struct.chrom_l       = chrom_l;
annotation_struct.top.chrom     = chrom_top;
annotation_struct.top.prime5    = g_top_5prime+chrom_l(annotation_struct.top.chrom);
annotation_struct.top.prime3    = g_top_3prime+chrom_l(annotation_struct.top.chrom);
annotation_struct.top.descr     = descr_top;
annotation_struct.top.GID       = GID_top;
annotation_struct.top.EID       = EID_top;
annotation_struct.top.TSS       = tss_top;
annotation_struct.bot.chrom     = chrom_bot;
annotation_struct.bot.prime5    = g_bot_5prime+chrom_l(annotation_struct.bot.chrom);
annotation_struct.bot.prime3    = g_bot_3prime+chrom_l(annotation_struct.bot.chrom);
annotation_struct.bot.descr     = descr_bot;
annotation_struct.bot.GID       = GID_bot;
annotation_struct.bot.EID       = EID_bot;
annotation_struct.bot.TSS       = tss_bot;
save annotation annotation_struct